import { Span, SpanAttributeValue, SpanAttributes, SpanContext, SpanContextData, SpanJSON, SpanStatus, SpanTimeInput, TraceContext, Transaction } from '@sentry/types';
/**
 * Span contains all data about a span
 */
export declare class SentrySpan implements Span {
    /**
     * Data for the span.
     * @deprecated Use `spanToJSON(span).atttributes` instead.
     */
    data: {
        [key: string]: any;
    };
    /**
     * @inheritDoc
     * @deprecated Use top level `Sentry.getRootSpan()` instead
     */
    transaction?: Transaction;
    protected _traceId: string;
    protected _spanId: string;
    protected _parentSpanId?: string | undefined;
    protected _sampled: boolean | undefined;
    protected _name?: string | undefined;
    protected _attributes: SpanAttributes;
    /** Epoch timestamp in seconds when the span started. */
    protected _startTime: number;
    /** Epoch timestamp in seconds when the span ended. */
    protected _endTime?: number | undefined;
    /** Internal keeper of the status */
    protected _status?: SpanStatus;
    private _logMessage?;
    /**
     * You should never call the constructor manually, always use `Sentry.startSpan()`
     * or other span methods.
     * @internal
     * @hideconstructor
     * @hidden
     */
    constructor(spanContext?: SpanContext);
    /*
    * The ID of the trace.
    * @deprecated Use `spanContext().traceId` instead.
    
    
    * The ID of the trace.
    * @deprecated You cannot update the traceId of a span after span creation.
    */
    traceId: string;
    /*
    * The ID of the span.
    * @deprecated Use `spanContext().spanId` instead.
    
    
    * The ID of the span.
    * @deprecated You cannot update the spanId of a span after span creation.
    */
    spanId: string;
    /*
    * @inheritDoc
    *
    * @deprecated Use `spanToJSON(span).parent_span_id` instead.
    
    
    * @inheritDoc
    *
    * @deprecated Use `startSpan` functions instead.
    */
    parentSpanId: string | undefined;
    /*
    * Was this span chosen to be sent as part of the sample?
    * @deprecated Use `isRecording()` instead.
    
    
    * Was this span chosen to be sent as part of the sample?
    * @deprecated You cannot update the sampling decision of a span after span creation.
    */
    sampled: boolean | undefined;
    /*
    * Attributes for the span.
    * @deprecated Use `spanToJSON(span).atttributes` instead.
    
    
    * Attributes for the span.
    * @deprecated Use `setAttributes()` instead.
    */
    attributes: SpanAttributes;
    /*
    * Timestamp in seconds (epoch time) indicating when the span started.
    * @deprecated Use `spanToJSON()` instead.
    
    
    * Timestamp in seconds (epoch time) indicating when the span started.
    * @deprecated In v8, you will not be able to update the span start time after creation.
    */
    startTimestamp: number;
    /*
    * Timestamp in seconds when the span ended.
    * @deprecated Use `spanToJSON()` instead.
    
    
    * Timestamp in seconds when the span ended.
    * @deprecated Set the end time via `span.end()` instead.
    */
    endTimestamp: number | undefined;
    /** @inheritdoc */
    spanContext(): SpanContextData;
    /**
     * Creates a new `Span` while setting the current `Span.id` as `parentSpanId`.
     * Also the `sampled` decision will be inherited.
     *
     * @deprecated Use `startSpan()`, `startSpanManual()` or `startInactiveSpan()` instead.
     */
    startChild(spanContext?: Pick<SpanContext, Exclude<keyof SpanContext, 'sampled' | 'traceId' | 'parentSpanId'>>): Span;
    /**
     * Sets the data attribute on the current span
     * @param key Data key
     * @param value Data value
     * @deprecated Use `setAttribute()` instead.
     */
    setData(key: string, value: any): this;
    /** @inheritdoc */
    setAttribute(key: string, value: SpanAttributeValue | undefined): void;
    /** @inheritdoc */
    setAttributes(attributes: SpanAttributes): void;
    /**
     * This should generally not be used,
     * but we need it for browser tracing where we want to adjust the start time afterwards.
     * USE THIS WITH CAUTION!
     *
     * @hidden
     * @internal
     */
    updateStartTime(timeInput: SpanTimeInput): void;
    /**
     * @inheritDoc
     */
    setStatus(value: SpanStatus): this;
    /**
     * @inheritDoc
     */
    updateName(name: string): this;
    /** @inheritdoc */
    end(endTimestamp?: SpanTimeInput): void;
    /**
     * @inheritDoc
     *
     * @deprecated Use `spanToJSON()` or access the fields directly instead.
     */
    toContext(): SpanContext;
    /**
     * @inheritDoc
     *
     * @deprecated Use `spanToTraceContext()` util function instead.
     */
    getTraceContext(): TraceContext;
    /**
     * Get JSON representation of this span.
     *
     * @hidden
     * @internal This method is purely for internal purposes and should not be used outside
     * of SDK code. If you need to get a JSON representation of a span,
     * use `spanToJSON(span)` instead.
     */
    getSpanJSON(): SpanJSON;
    /** @inheritdoc */
    isRecording(): boolean;
    /**
     * Convert the object to JSON.
     * @deprecated Use `spanToJSON(span)` instead.
     */
    toJSON(): SpanJSON;
    /**
     * Get the merged data for this span.
     * For now, this combines `data` and `attributes` together,
     * until eventually we can ingest `attributes` directly.
     */
    private _getData;
    /** Emit `spanEnd` when the span is ended. */
    private _onSpanEnded;
}
//# sourceMappingURL=sentrySpan.d.ts.map
